package org.apache.batik.ext.awt.image.codec.jpeg;

import java.awt.image.BufferedImage;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;

import org.apache.batik.ext.awt.image.spi.ImageWriterParams;

import junit.framework.TestCase;

public class JPEGImageWriterTest extends TestCase {
    private BufferedImage image;
    private ByteArrayOutputStream out;
    private JPEGImageWriter imageWriter;

    public void setUp() {
        out = new ByteArrayOutputStream();
        imageWriter = new JPEGImageWriter();
        image = new BufferedImage(200, 200, BufferedImage.TYPE_BYTE_GRAY);
    }

    public void testJPEGWriting() throws Exception {
        imageWriter.writeImage(image, out);
        assertCanReadBack();
    }

    public void testJPEGWritingQuality() throws Exception {

        ImageWriterParams params = new ImageWriterParams();
        params.setJPEGQuality(0.5f, false);
        imageWriter.writeImage(image, out, params);
        assertCanReadBack();
    }

    private void assertCanReadBack() throws Exception {
        // try reading it back
        ImageReader rdr = (ImageReader) ImageIO.getImageReadersByMIMEType("image/jpeg").next();
        ImageInputStream is = ImageIO.createImageInputStream(new ByteArrayInputStream(out.toByteArray()));
        rdr.setInput(is);
        BufferedImage image2 = rdr.read(0);
        assertEquals(200, image2.getHeight());
        assertEquals(200, image2.getWidth());
    }
}
